@@ -270,11 +270,12 @@ showUpdateTablesMsg <- function() {
 getJuliaExecutablePath <- function() {
    juliaBindir <- Sys.getenv("JULIA_BINDIR")
    if (juliaBindir == "") {
-      if (nchar(Sys.which("julia")) == 0) {
-         stop("Julia not found in path. Please check your Julia setup.")
+      if (Sys.which("julia") == "") {
+         juliaCmd <- fallbackOnDefaultJuliaupPath()
+      } else { # Julia is on the PATH, simply use the command "julia"
+         juliaCmd <- "julia"
       }
-      juliaCmd <- "julia"
-   } else {
+   } else { # use the JULIA_BINDIR variable, as it is specified
       juliaExe <- list.files(path = juliaBindir, pattern = "^julia.*")
       if (length(juliaExe) == 0) {
          stop(paste0("No Julia executable file found in supposed bin directory \"" ,
@@ -286,6 +287,25 @@ getJuliaExecutablePath <- function() {
 }
 
 
+fallbackOnDefaultJuliaupPath <- function() {
+   # If Julia is not found on the PATH, check the default Juliaup installation location
+   # on Linux and Mac and use the Julia command there if it exists.
+   # (On Mac, Julia might not be on the PATH in the R session even though
+   # Julia has been installed in the default way via Juliaup.)
+   juliaCmd <- file.path(Sys.getenv("HOME"), ".juliaup", "bin", "julia")
+   if (!file.exists(juliaCmd) || Sys.info()['sysname'] == "Windows") {
+      stop('Julia could not be found.
+Julia needs to be installed and findable for the "JuliaConnectoR" package to work.
+After installing Julia, the best way make Julia findable is to put the folder containing the Julia executable into the PATH environment variable.
+For more information, see the help topic ?`Julia-Setup`.
+')
+   } else {
+      return(juliaCmd)
+   }
+}
+
+
+#
 #' Stop the connection to Julia
 #'
 #' This ends the connection to Julia. Julia terminates if no R process is
