@@ -1109,6 +1109,17 @@ test_that("Error if Julia is not setup properly", {
 })
 
 
+test_that("Fallback on juliaup fails correctly", {
+   skip_on_cran()
+   juliaCmdJuliaup <- file.path(Sys.getenv("HOME"), ".juliaup", "bin", "julia")
+   if (!file.exists(juliaCmdJuliaup)) {
+      expect_error(JuliaConnectoR:::fallbackOnDefaultJuliaupPath(), regexp = "\\?`Julia-Setup`")
+   } else {
+      expect_equal(juliaCmdJuliaup, JuliaConnectoR:::fallbackOnDefaultJuliaupPath())
+   }
+})
+
+
 test_that("Circular references do not lead to a crash", {
 
    definition <- 'mutable struct TestRecur
@@ -1354,8 +1365,10 @@ test_that("Data frame can be translated", {
    Pkg <- juliaImport("Pkg")
    if (juliaEval('VERSION < v"1.6"')) {
       subproject <- "1_0"
-   } else {
+   } else if (juliaEval('VERSION < v"1.10"')) {
       subproject <- "1_6"
+   } else {
+      subproject <- "1_10"
    }
    Pkg$activate(system.file("examples", "IndexedTables-Project", subproject,
                             package = "JuliaConnectoR"))
